==> tensorlayerx-0.5.7.tar.gz: tensorlayerx-0.5.7/tensorlayerx/backend/ops/__init__.py <==
#! /usr/bin/python
# -*- coding: utf-8 -*-

# load nn ops
from .load_backend import padding_format
from .load_backend import preprocess_1d_format
from .load_backend import preprocess_2d_format
from .load_backend import preprocess_3d_format
from .load_backend import nchw_to_nhwc
from .load_backend import nhwc_to_nchw
from .load_backend import relu
from .load_backend import elu
from .load_backend import relu6
from .load_backend import prelu
from .load_backend import leaky_relu
from .load_backend import sigmoid
from .load_backend import softmax
from .load_backend import gelu
from .load_backend import bias_add
from .load_backend import conv1d
from .load_backend import conv2d
from .load_backend import conv3d
from .load_backend import lrn
from .load_backend import moments
from .load_backend import max_pool
from .load_backend import avg_pool
from .load_backend import max_pool3d
from .load_backend import avg_pool3d
from .load_backend import pool
from .load_backend import depthwise_conv2d
from .load_backend import Conv1d_transpose
from .load_backend import Conv2d_transpose
from .load_backend import Conv3d_transpose
from .load_backend import GroupConv2D
from .load_backend import BinaryConv2D
from .load_backend import DorefaConv2D
from .load_backend import rnncell
from .load_backend import lstmcell
from .load_backend import grucell
from .load_backend import rnnbase
from .load_backend import layernorm
from .load_backend import multiheadattention

from .load_backend import ReLU
from .load_backend import ELU
from .load_backend import ReLU6
from .load_backend import PReLU
from .load_backend import LeakyReLU
from .load_backend import Softplus
from .load_backend import Tanh
from .load_backend import Sigmoid
from .load_backend import Softmax
from .load_backend import GeLU
from .load_backend import Conv1D
from .load_backend import Conv2D
from .load_backend import Conv3D
from .load_backend import BiasAdd
from .load_backend import MaxPool1d
from .load_backend import MaxPool
from .load_backend import MaxPool3d
from .load_backend import AvgPool1d
from .load_backend import AvgPool
from .load_backend import AvgPool3d
from .load_backend import Dropout
from .load_backend import BatchNorm
from .load_backend import DepthwiseConv2d
from .load_backend import SeparableConv1D
from .load_backend import SeparableConv2D
from .load_backend import AdaptiveMeanPool1D
from .load_backend import AdaptiveMeanPool2D
from .load_backend import AdaptiveMeanPool3D
from .load_backend import AdaptiveMaxPool1D
from .load_backend import AdaptiveMaxPool2D
from .load_backend import AdaptiveMaxPool3D
from .load_backend import Floor
from .load_backend import Ceil
from .load_backend import BinaryDense
from .load_backend import DorefaDense
from .load_backend import TernaryDense
from .load_backend import QuanDense
from .load_backend import QuanDenseBn
from .load_backend import TernaryConv
from .load_backend import QuanConv
from .load_backend import QuanConvBn

# load ops
from .load_backend import Variable
from .load_backend import matmul
from .load_backend import add
from .load_backend import dtypes
from .load_backend import minimum
from .load_backend import reshape
from .load_backend import concat
from .load_backend import convert_to_tensor
from .load_backend import convert_to_numpy
from .load_backend import sqrt
from .load_backend import reduce_mean
from .load_backend import reduce_min
from .load_backend import reduce_max
from .load_backend import pad
from .load_backend import stack
from .load_backend import meshgrid
from .load_backend import arange
from .load_backend import expand_dims
from .load_backend import tile
from .load_backend import cast
from .load_backend import transpose
from .load_backend import gather_nd
from .load_backend import scatter_nd
from .load_backend import clip_by_value
from .load_backend import split
from .load_backend import get_tensor_shape
from .load_backend import set_context
from .load_backend import resize
from .load_backend import floor
from .load_backend import gather
from .load_backend import linspace
from .load_backend import slice
from .load_backend import add_n
from .load_backend import ceil
from .load_backend import multiply
from .load_backend import divide
from .load_backend import identity
from .load_backend import triu
from .load_backend import tril
from .load_backend import abs
from .load_backend import acos
from .load_backend import acosh
from .load_backend import angle
from .load_backend import argmax
from .load_backend import argmin
from .load_backend import asin
from .load_backend import asinh
from .load_backend import atan
from .load_backend import atanh
from .load_backend import cos
from .load_backend import cosh
from .load_backend import count_nonzero
from .load_backend import cumprod
from .load_backend import cumsum
from .load_backend import equal
from .load_backend import exp
from .load_backend import floordiv
from .load_backend import floormod
from .load_backend import greater
from .load_backend import greater_equal
from .load_backend import is_inf
from .load_backend import is_nan
from .load_backend import l2_normalize
from .load_backend import less
from .load_backend import less_equal
from .load_backend import log
from .load_backend import log_sigmoid
from .load_backend import maximum
from .load_backend import negative
from .load_backend import not_equal
from .load_backend import pow
from .load_backend import real
from .load_backend import reciprocal
from .load_backend import reduce_prod
from .load_backend import reduce_std
from .load_backend import reduce_sum
from .load_backend import reduce_variance
from .load_backend import round
from .load_backend import rsqrt
from .load_backend import segment_max
from .load_backend import segment_mean
from .load_backend import segment_min
from .load_backend import segment_prod
from .load_backend import segment_sum
from .load_backend import sign
from .load_backend import sin
from .load_backend import sinh
from .load_backend import softplus
from .load_backend import square
from .load_backend import squared_difference
from .load_backend import subtract
from .load_backend import tan
from .load_backend import tanh
from .load_backend import any
from .load_backend import all
from .load_backend import logical_and
from .load_backend import logical_or
from .load_backend import logical_not
from .load_backend import logical_xor
from .load_backend import argsort
from .load_backend import bmm
from .load_backend import where
from .load_backend import ones_like
from .load_backend import zeros_like
from .load_backend import squeeze
from .load_backend import unsorted_segment_sum
from .load_backend import unsorted_segment_min
from .load_backend import unsorted_segment_mean
from .load_backend import unsorted_segment_max
from .load_backend import set_seed
from .load_backend import is_tensor
from .load_backend import tensor_scatter_nd_update
from .load_backend import diag
from .load_backend import mask_select
from .load_backend import eye
from .load_backend import einsum
from .load_backend import set_device
from .load_backend import get_device
from .load_backend import scatter_update
from .load_backend import to_device
from .load_backend import roll
from .load_backend import logsoftmax
# dtype
from .load_backend import (
    DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
    complex128
)
# initlizers
from .load_backend import (
    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, he_uniform, xavier_normal, xavier_uniform
)
# backend
from .load_backend import BACKEND
from .load_backend import BACKEND_VERSION

from .load_backend import Reshape
from .load_backend import ReduceSum
from .load_backend import ReduceMax
from .load_backend import ReduceMean
from .load_backend import OneHot
from .load_backend import L2Normalize
from .load_backend import EmbeddingLookup
from .load_backend import NCELoss
from .load_backend import NotEqual
from .load_backend import Cast
from .load_backend import ExpandDims
from .load_backend import CountNonzero
from .load_backend import FlattenReshape
from .load_backend import Transpose
from .load_backend import MatMul
from .load_backend import Tile
from .load_backend import Concat
from .load_backend import ZeroPadding1D
from .load_backend import ZeroPadding2D
from .load_backend import ZeroPadding3D
from .load_backend import Stack
from .load_backend import Unstack
from .load_backend import Sign
from .load_backend import Resize
from .load_backend import Pad
from .load_backend import Minimum
from .load_backend import Maximum
from .load_backend import Meshgrid
from .load_backend import BatchToSpace
from .load_backend import DepthToSpace
from .load_backend import ClipGradByValue
from .load_backend import ClipGradByNorm
from .load_backend import ClipByGlobalNorm
from .load_backend import Einsum

==> tensorlayerx-0.5.8.tar.gz: tensorlayerx-0.5.8/tensorlayerx/backend/ops/__init__.py <==
#! /usr/bin/python
# -*- coding: utf-8 -*-

# load nn ops
from .load_backend import padding_format
from .load_backend import preprocess_1d_format
from .load_backend import preprocess_2d_format
from .load_backend import preprocess_3d_format
from .load_backend import nchw_to_nhwc
from .load_backend import nhwc_to_nchw
from .load_backend import relu
from .load_backend import elu
from .load_backend import relu6
from .load_backend import prelu
from .load_backend import leaky_relu
from .load_backend import sigmoid
from .load_backend import softmax
from .load_backend import gelu
from .load_backend import bias_add
from .load_backend import conv1d
from .load_backend import conv2d
from .load_backend import conv3d
from .load_backend import lrn
from .load_backend import moments
from .load_backend import max_pool
from .load_backend import avg_pool
from .load_backend import max_pool3d
from .load_backend import avg_pool3d
from .load_backend import pool
from .load_backend import depthwise_conv2d
from .load_backend import Conv1d_transpose
from .load_backend import Conv2d_transpose
from .load_backend import Conv3d_transpose
from .load_backend import GroupConv2D
from .load_backend import BinaryConv2D
from .load_backend import DorefaConv2D
from .load_backend import rnncell
from .load_backend import lstmcell
from .load_backend import grucell
from .load_backend import rnnbase
from .load_backend import layernorm
from .load_backend import multiheadattention
from .load_backend import histogram
from .load_backend import flatten
from .load_backend import interpolate
from .load_backend import index_select
from .load_backend import dot

from .load_backend import ReLU
from .load_backend import ELU
from .load_backend import ReLU6
from .load_backend import PReLU
from .load_backend import LeakyReLU
from .load_backend import Softplus
from .load_backend import Tanh
from .load_backend import Sigmoid
from .load_backend import Softmax
from .load_backend import GeLU
from .load_backend import Conv1D
from .load_backend import Conv2D
from .load_backend import Conv3D
from .load_backend import BiasAdd
from .load_backend import MaxPool1d
from .load_backend import MaxPool
from .load_backend import MaxPool3d
from .load_backend import AvgPool1d
from .load_backend import AvgPool
from .load_backend import AvgPool3d
from .load_backend import Dropout
from .load_backend import BatchNorm
from .load_backend import DepthwiseConv2d
from .load_backend import SeparableConv1D
from .load_backend import SeparableConv2D
from .load_backend import AdaptiveMeanPool1D
from .load_backend import AdaptiveMeanPool2D
from .load_backend import AdaptiveMeanPool3D
from .load_backend import AdaptiveMaxPool1D
from .load_backend import AdaptiveMaxPool2D
from .load_backend import AdaptiveMaxPool3D
from .load_backend import Floor
from .load_backend import Ceil
from .load_backend import BinaryDense
from .load_backend import DorefaDense
from .load_backend import TernaryDense
from .load_backend import QuanDense
from .load_backend import QuanDenseBn
from .load_backend import TernaryConv
from .load_backend import QuanConv
from .load_backend import QuanConvBn
from .load_backend import Swish

# load ops
from .load_backend import Variable
from .load_backend import matmul
from .load_backend import add
from .load_backend import dtypes
from .load_backend import minimum
from .load_backend import reshape
from .load_backend import concat
from .load_backend import convert_to_tensor
from .load_backend import convert_to_numpy
from .load_backend import sqrt
from .load_backend import reduce_mean
from .load_backend import reduce_min
from .load_backend import reduce_max
from .load_backend import pad
from .load_backend import stack
from .load_backend import meshgrid
from .load_backend import arange
from .load_backend import expand_dims
from .load_backend import tile
from .load_backend import cast
from .load_backend import transpose
from .load_backend import gather_nd
from .load_backend import scatter_nd
from .load_backend import clip_by_value
from .load_backend import split
from .load_backend import get_tensor_shape
from .load_backend import set_context
from .load_backend import resize
from .load_backend import floor
from .load_backend import gather
from .load_backend import linspace
from .load_backend import slice
from .load_backend import add_n
from .load_backend import ceil
from .load_backend import multiply
from .load_backend import divide
from .load_backend import identity
from .load_backend import triu
from .load_backend import tril
from .load_backend import abs
from .load_backend import acos
from .load_backend import acosh
from .load_backend import angle
from .load_backend import argmax
from .load_backend import argmin
from .load_backend import asin
from .load_backend import asinh
from .load_backend import atan
from .load_backend import atanh
from .load_backend import cos
from .load_backend import cosh
from .load_backend import count_nonzero
from .load_backend import cumprod
from .load_backend import cumsum
from .load_backend import equal
from .load_backend import exp
from .load_backend import floordiv
from .load_backend import floormod
from .load_backend import greater
from .load_backend import greater_equal
from .load_backend import is_inf
from .load_backend import is_nan
from .load_backend import l2_normalize
from .load_backend import less
from .load_backend import less_equal
from .load_backend import log
from .load_backend import log_sigmoid
from .load_backend import maximum
from .load_backend import negative
from .load_backend import not_equal
from .load_backend import pow
from .load_backend import real
from .load_backend import reciprocal
from .load_backend import reduce_prod
from .load_backend import reduce_std
from .load_backend import reduce_sum
from .load_backend import reduce_variance
from .load_backend import round
from .load_backend import rsqrt
from .load_backend import segment_max
from .load_backend import segment_mean
from .load_backend import segment_min
from .load_backend import segment_prod
from .load_backend import segment_sum
from .load_backend import sign
from .load_backend import sin
from .load_backend import sinh
from .load_backend import softplus
from .load_backend import square
from .load_backend import squared_difference
from .load_backend import subtract
from .load_backend import tan
from .load_backend import tanh
from .load_backend import any
from .load_backend import all
from .load_backend import logical_and
from .load_backend import logical_or
from .load_backend import logical_not
from .load_backend import logical_xor
from .load_backend import argsort
from .load_backend import bmm
from .load_backend import where
from .load_backend import ones_like
from .load_backend import zeros_like
from .load_backend import squeeze
from .load_backend import unsorted_segment_sum
from .load_backend import unsorted_segment_min
from .load_backend import unsorted_segment_mean
from .load_backend import unsorted_segment_max
from .load_backend import set_seed
from .load_backend import is_tensor
from .load_backend import tensor_scatter_nd_update
from .load_backend import diag
from .load_backend import mask_select
from .load_backend import eye
from .load_backend import einsum
from .load_backend import set_device
from .load_backend import get_device
from .load_backend import scatter_update
from .load_backend import to_device
from .load_backend import roll
from .load_backend import logsoftmax
from .load_backend import topk
from .load_backend import hardsigmoid
from .load_backend import numel
from .load_backend import hardswish
from .load_backend import swish
from .load_backend import expand
from .load_backend import unique
from .load_backend import flip
from .load_backend import mv
# dtype
from .load_backend import (
    DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
    complex128
)
# initlizers
from .load_backend import (
    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, he_uniform, xavier_normal, xavier_uniform
)
# backend
from .load_backend import BACKEND
from .load_backend import BACKEND_VERSION

from .load_backend import Reshape
from .load_backend import ReduceSum
from .load_backend import ReduceMax
from .load_backend import ReduceMean
from .load_backend import OneHot
from .load_backend import L2Normalize
from .load_backend import EmbeddingLookup
from .load_backend import NCELoss
from .load_backend import NotEqual
from .load_backend import Cast
from .load_backend import ExpandDims
from .load_backend import CountNonzero
from .load_backend import FlattenReshape
from .load_backend import Transpose
from .load_backend import MatMul
from .load_backend import Tile
from .load_backend import Concat
from .load_backend import ZeroPadding1D
from .load_backend import ZeroPadding2D
from .load_backend import ZeroPadding3D
from .load_backend import Stack
from .load_backend import Unstack
from .load_backend import Sign
from .load_backend import Resize
from .load_backend import Pad
from .load_backend import Pad2d
from .load_backend import Minimum
from .load_backend import Maximum
from .load_backend import Meshgrid
from .load_backend import BatchToSpace
from .load_backend import DepthToSpace
from .load_backend import ClipGradByValue
from .load_backend import ClipGradByNorm
from .load_backend import ClipByGlobalNorm
from .load_backend import Einsum
from .load_backend import linear
from .load_backend import adaptive_avg_pool1d
from .load_backend import adaptive_avg_pool2d
from .load_backend import adaptive_avg_pool3d
from .load_backend import adaptive_max_pool1d
from .load_backend import adaptive_max_pool2d
from .load_backend import adaptive_max_pool3d
from .load_backend import unfold
from .load_backend import avg_pool1d
from .load_backend import avg_pool2d
from .load_backend import avg_pool3d
from .load_backend import max_pool1d
from .load_backend import max_pool2d
from .load_backend import max_pool3d
from .load_backend import conv2d_transpose
